[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
30/91: gnu: python-dateutil: Move to pyproject-build-system.
From: |
guix-commits |
Subject: |
30/91: gnu: python-dateutil: Move to pyproject-build-system. |
Date: |
Thu, 23 May 2024 17:17:30 -0400 (EDT) |
ngz pushed a commit to branch python-team
in repository guix.
commit b6c7e2572a6431f12bdeef0d152114b472c5958e
Author: Nicolas Graves <ngraves@ngraves.fr>
AuthorDate: Fri May 10 00:53:25 2024 +0200
gnu: python-dateutil: Move to pyproject-build-system.
* gnu/packages/time.scm (python-dateutil): Improve package style.
[build-system]: Move to pyproject-build-system.
[arguments]: Use <#:test-flags> instead of check phase replacement.
Change-Id: I252fbe47f04ba6a2fbcc497565cbf6e352f9d06c
Signed-off-by: Nicolas Goaziou <mail@nicolasgoaziou.fr>
---
gnu/packages/time.scm | 23 ++++++++---------------
1 file changed, 8 insertions(+), 15 deletions(-)
diff --git a/gnu/packages/time.scm b/gnu/packages/time.scm
index 96fe9f561a..552ac346c4 100644
--- a/gnu/packages/time.scm
+++ b/gnu/packages/time.scm
@@ -242,22 +242,15 @@ Pendulum instances.")
(uri (pypi-uri "python-dateutil" version))
(patches (search-patches "python-dateutil-pytest-compat.patch"))
(sha256
- (base32
- "11iy7m4bp2lgfkcl0r6xzf34bvk7ppjmsyn2ygfikbi72v6cl8q1"))))
- (build-system python-build-system)
+ (base32 "11iy7m4bp2lgfkcl0r6xzf34bvk7ppjmsyn2ygfikbi72v6cl8q1"))))
+ (build-system pyproject-build-system)
(arguments
- `(#:phases (modify-phases %standard-phases
- (replace 'check
- (lambda _
- ;; Delete tests that depend on "freezegun" to avoid a
- ;; circular dependency.
- (delete-file "dateutil/test/test_utils.py")
- (delete-file "dateutil/test/test_rrule.py")
-
- ;; XXX: Fails to get timezone from /etc/localtime.
- (delete-file "dateutil/test/test_tz.py")
-
- (invoke "pytest" "-vv"))))))
+ (list
+ #:test-flags '(list ; avoid freezegun dependency
+ "--ignore=dateutil/test/test_utils.py"
+ "--ignore=dateutil/test/test_rrule.py"
+ ;; XXX: Fails to get timezone from /etc/localtime.
+ "--ignore=dateutil/test/test_tz.py")))
(native-inputs
(list python-pytest python-pytest-cov python-setuptools-scm))
(propagated-inputs
- 28/91: gnu: zulip-term: Move to pyproject-build-system., (continued)
- 28/91: gnu: zulip-term: Move to pyproject-build-system., guix-commits, 2024/05/23
- 48/91: gnu: python-pytest-remotedata: Ignore failing test., guix-commits, 2024/05/23
- 37/91: gnu: python-tinycss: Move to pyproject-build-system., guix-commits, 2024/05/23
- 35/91: gnu: python-unidecode: Update to 1.3.8., guix-commits, 2024/05/23
- 39/91: gnu: python-cucumber-tag-expressions: Move to pyproject-build-system., guix-commits, 2024/05/23
- 24/91: gnu: python-scikit-rf: Fix tests., guix-commits, 2024/05/23
- 33/91: gnu: python-pytest-runner: Improve package style., guix-commits, 2024/05/23
- 47/91: gnu: abjad-ext-nauert: Update to 3.19., guix-commits, 2024/05/23
- 22/91: gnu: conda: Reindent., guix-commits, 2024/05/23
- 25/91: gnu: gunicorn: Move to pyproject-build-system., guix-commits, 2024/05/23
- 30/91: gnu: python-dateutil: Move to pyproject-build-system.,
guix-commits <=
- 44/91: gnu: python-sphinx-autodoc-typehints: Move to pyproject-build-system., guix-commits, 2024/05/23
- 41/91: gnu: python-parse-type: Move to pyproject-build-system., guix-commits, 2024/05/23
- 21/91: gnu: conda: Move to pyproject-build-system., guix-commits, 2024/05/23
- 46/91: gnu: abjad-ext-rmakers: Update to 3.19., guix-commits, 2024/05/23
- 50/91: gnu: python-cairosvg: Move to pyproject-build-system., guix-commits, 2024/05/23
- 56/91: gnu: python-jaraco-test: Move to pyproject-build-system., guix-commits, 2024/05/23
- 66/91: gnu: python-flake8-isort: Move to pyproject-build-system., guix-commits, 2024/05/23
- 63/91: gnu: python-autoflake: Update to 2.3.1., guix-commits, 2024/05/23
- 70/91: gnu: Add python-sphinx-autodoc-typehints-5., guix-commits, 2024/05/23
- 69/91: gnu: python-cmd2: Move to pyproject-build-system., guix-commits, 2024/05/23